<?php
/**
 * @file
 * Contains Batch API callbacks used during installation.
 */

/**
 * BatchAPI callback.
 *
 * @see drop_jobs_install_additional_modules()
 */
function _drop_jobs_enable_module($module, $module_name, &$context) {
  module_enable(array($module), FALSE);
  $context['message'] = st('Installed %module module.', array('%module' => $module_name));
}

/**
 * BatchAPI callback.
 *
 * @see drop_jobs_install_additional_modules()
 */
function _drop_jobs_flush_caches($operation, &$context) {
  $context['message'] = t('@operation', array('@operation' => $operation));
  drupal_flush_all_caches();
}

/**
 * BatchAPI callback.
 *
 * @see drop_jobs_import_content()
 */
function _drop_jobs_import($operation, $type, &$context) {
  $context['message'] = t('@operation', array('@operation' => $type));
  $migration =  Migration::getInstance($operation);
  $migration->processImport();
}

/**
 * BatchAPI callback.
 *
 * @see drop_jobs_core_demo_rollback()
 */
function _drop_jobs_rollback($operation, $type, &$context) {
  $context['message'] = t('@operation', array('@operation' => $type));
  $migration =  Migration::getInstance($operation);
  $migration->processRollback();
}

/**
 * Batch API finished callback.
 *
 * @see drop_jobs_import_content()
 * @see drop_jobs_core_demo_import()
 */
function drop_jobs_import_content_finished($success, $results) {
  // Remove messages generated by Migrate.
  drupal_get_messages(NULL, TRUE);

  if ($success) {
    drupal_set_message(t('Finished importing demo content.'), 'status', FALSE);
  }
  else {
    drupal_set_message(t('Error importing demo content.'), 'error', FALSE);
  }
}

/**
 * Batch API finished callback.
 *
 * @see drop_jobs_import_terms()
 */
function drop_jobs_import_terms_finished($success, $results) {
  // Remove messages generated by Migrate.
  drupal_get_messages(NULL, TRUE);

  if ($success) {
    drupal_set_message(t('Finished importing taxonomy terms.'), 'status', FALSE);
  }
  else {
    drupal_set_message(t('Error importing taxonomy terms.'), 'error', FALSE);
  }
}

/**
 * Batch API finished callback.
 *
 * @see drop_jobs_core_demo_rollback()
 */
function drop_jobs_rollback_content_finished($success, $results) {
  // Remove messages generated by Migrate.
  drupal_get_messages(NULL, TRUE);

  if ($success) {
    drupal_set_message(t('Finished removing demo content.'), 'status', FALSE);
  }
  else {
    drupal_set_message(t('Error removing demo content.'), 'error', FALSE);
  }
}