<?php
/**
 * @file
 * Drop Jobs Candidate Rules integration.
 */

/**
 * Access callback.
 *
 * @see drop_jobs_candidate_rules_event_info()
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_rules_access($type, $name) {
  if ($type === 'event' || $type === 'condition') {
    return user_access('administer drop_jobs_candidate');
  }
}

/**
 * Implements hook_rules_event_info().
 *
 * Defines rules events.
 */
function drop_jobs_candidate_rules_event_info() {
  $events = array();

  // For the sake of convenience.
  $defaults = array(
    'group' => t('Drop Jobs Candidate'),
    'access callback' => 'drop_jobs_candidate_rules_access',
    'variables' => array(
      'profile' => array(
        'label' => t('Candidate profile object'),
        'type' => 'profile2',
        'skip save' => TRUE,
      ),
    ),
  );

  // Candidate résumé becomes complete.
  $events['drop_jobs_candidate_complete'] = array(
    'label' => t('Candidate completes his résumé.'),
    ) + $defaults;

  // Candidate résumé becomes incomplete.
  $events['drop_jobs_candidate_incomplete'] = array(
    'label' => t('Candidate un-completes his résumé.'),
    ) + $defaults;

  // Candidate résumé becomes active.
  $events['drop_jobs_candidate_visible'] = array(
    'label' => t('Résumé set to visible.'),
    ) + $defaults;

  // Candidate résumé becomes inactive.
  $events['drop_jobs_candidate_hidden'] = array(
    'label' => t('Résumé set to hidden.'),
    ) + $defaults;

  return $events;
}

/**
 * Implements hook_rules_condition_info().
 */
function drop_jobs_candidate_rules_condition_info() {
  $conditions = array();

  // For convenience.
  $defaults = array(
    'group' => t('Drop Jobs Candidate'),
    'parameter' => array(
      'profile' => array(
        'label' => t('Candidate profile object'),
        'type' => 'profile2',
        'skip save' => TRUE,
      ),
    ),
  );

  $conditions['drop_jobs_candidate_visible'] = array(
    'label' => t("Check whether a given candidate's résumé is active"),
    'base' => 'drop_jobs_candidate_condition_visible',
    ) + $defaults;

  $conditions['drop_jobs_candidate_hidden'] = array(
    'label' => t("Check whether a given candidate's résumé is inactive"),
    'base' => 'drop_jobs_candidate_condition_hidden',
    ) + $defaults;

  return $conditions;
}

/**
 * Implements hook_rules_action_info().
 */
function drop_jobs_candidate_rules_action_info() {
  $actions = array();

  // For convenience.
  $defaults = array(
    'group' => t('Drop Jobs Candidate'),
    'access callback' => 'drop_jobs_candidate_rules_access',
    'parameter' => array(
      'profile' => array(
        'type' => 'profile2',
        'label' => t('Profile object'),
        'save' => FALSE,
      ),
    ),
  );

  // Show a resume.
  $actions['drop_jobs_candidate_visible'] = array(
    'label' => t('Make a résumé as visible'),
    'base' => 'drop_jobs_candidate_action_visible',
    ) + $defaults;

  // Hide a resume.
  $actions['drop_jobs_candidate_hidden'] = array(
    'label' => t('Make a résumé as hidden'),
    'base' => 'drop_jobs_candidate_action_hidden',
    ) + $defaults;

  return $actions;
}

/**
 * Rules condition callback.
 * Checks whether a given profile is active.
 *
 * @see drop_jobs_candidate_rules_condition_info()
 */
function drop_jobs_candidate_condition_visible(Profile $profile) {
  return drop_jobs_candidate_resume_is_visible($profile);
}

/**
 * Rules condition callback.
 * Checks whether a given profile is inactive.
 *
 * @see drop_jobs_candidate_rules_condition_info()
 */
function drop_jobs_candidate_condition_hidden(Profile $profile) {
  return !drop_jobs_candidate_resume_is_visible($profile);
}

/**
 * Rules action callback.
 * Marks a given profile as active.
 *
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_action_visible(Profile $profile) {
  return drop_jobs_candidate_resume_set_visible($profile);
}

/**
 * Rules action callback.
 * Marks a given profile as inactive.
 *
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_action_hidden(Profile $profile) {
  return drop_jobs_candidate_resume_set_hidden($profile);
}
