<?php
/**
 * @file
 * Candidates migration class for Drop Jobs Demo.
 */

/**
 * Class for importing employer profiles.
 */
class DropJobsCandidates extends DropJobsMigration {

  public function __construct() {
    parent::__construct();
    $this->description = t('Import Candidate profiles.');
    $this->softDependencies = array('DropJobsUsers');

    $this->map = new MigrateSQLMap($this->machineName,
      array(
        'id' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => TRUE,
        )
      ),
      MigrateDestinationProfile2::getKeySchema()
    );

    $this->source = new MigrateSourceCSV(drupal_get_path('module', 'drop_jobs_demo') . '/import/candidate.csv', $this->csvcolumns(), array('header_rows' => 1));

    $this->destination = new MigrateDestinationProfile2('candidate');

    $this->addFieldMapping('uid', 'user')->defaultValue(1)->sourceMigration('DropJobsUsers');

    $this->addFieldMapping('field_candidate_visible', 'active');
    $this->addFieldMapping('field_candidate_promoted', 'promoted');
    $this->addFieldMapping('field_candidate_sticky', 'sticky');
    $this->addFieldMapping('field_candidate_state', 'profile_state');

    $this->addUnmigratedDestinations(array(
      'revision_uid',
      'language',
      'field_candidate_attachments',
      'field_candidate_attachments:file_class',
      'field_candidate_attachments:language',
      'field_candidate_attachments:destination_dir',
      'field_candidate_attachments:destination_file',
      'field_candidate_attachments:file_replace',
      'field_candidate_attachments:preserve_files',
      'field_candidate_attachments:source_dir',
      'field_candidate_attachments:description',
      'field_candidate_attachments:display',
      // These are ignored for now because we must first migrate this Profile
      // entity and then the Field Collection Items.
      'field_candidate_personal_info',
      'field_candidate_languages',
      'field_candidate_education',
      'field_candidate_job_prefs',
      'field_candidate_skills',
      'field_candidate_experience',
    ));

    $this->addUnmigratedSources(array(
      'id',
    ));
  }

  public function csvcolumns() {
    return array(
      array('id', 'User id'),
      array('user', 'User name'),
      array('active', 'Candidate profile active flag'),
      array('promoted', 'Candidate profile promoted flag'),
      array('sticky', 'Candidate profile sticky flag'),
      array('profile_state', 'Candidate profile state'),
    );
  }

}