<?php
/**
 * @file
 * Candidates Language Info migration class for Drop Jobs Demo.
 *
 * This is a separate migration because this particular field is a field
 * collection.
 */

/**
 * Class for importing field collection items from the language info bundle.
 */
class DropJobsCandidatesLanguage extends DropJobsMigration {

  public function __construct() {
//    $this->sourceFields['level'] = t('Term level, extracted in prepareRow()');

    parent::__construct();
    $this->description = t("Import candidate profiles' language info field collection items.");
    $this->dependencies = array('DropJobsCandidates');

    $this->map = new MigrateSQLMap($this->machineName,
      array(
        'dummy_id' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => TRUE,
        )
      ),
      MigrateDestinationFieldCollection::getKeySchema()
    );

    // We use the same CSV as from the candidate profile migration.
    $this->source = new MigrateSourceCSV(drupal_get_path('module', 'drop_jobs_demo') . '/import/candidate_language.csv', $this->csvcolumns(), array('header_rows' => 1));

    $this->destination = new MigrateDestinationFieldCollection('field_candidate_languages', array(
      'host_entity_type' => 'profile2'
    ));

    $this->addFieldMapping('host_entity_id', 'id')
      ->sourceMigration('DropJobsCandidates');

    $this->addFieldMapping('field_candidate_notes', 'notes');

    $this->addFieldMapping('field_candidate_language', 'languages')
      ->separator(',');
    $this->addFieldMapping('field_candidate_language:level', 'level')
      ->separator(',');

    $this->addUnmigratedDestinations(array(
      'field_candidate_notes:language',
    ));

    $this->addUnmigratedSources(array(
      'user',
    ));
  }

  public function csvcolumns() {
    return array(
      array('dummy_id', 'Dummy item id'),
      array('id', 'User id'),
      array('user', 'User name'),
      array('languages', 'Candidate language'),
      array('notes', 'Candidate language notes'),
    );
  }

  function prepareRow($row) {
    parent::prepareRow($row);

    // Prepare languages data.
    $this->_parseTermLevel($row, 'languages', 'languages', ',');

    return TRUE;
  }

}