<?php
/**
 * @file
 * Candidates Personal Info migration class for Drop Jobs Demo.
 *
 * This is a separate migration because this particular field is a field
 * collection.
 */

/**
 * Class for importing field collection items from the personal info bundle.
 */
class DropJobsCandidatesPersonal extends DropJobsMigration {

  public function __construct() {
    parent::__construct();
    $this->description = t("Import candidate profiles' personal info field collection items.");
    $this->dependencies = array('DropJobsCandidates');

    $this->map = new MigrateSQLMap($this->machineName,
      array(
        'id' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => TRUE,
        )
      ),
      MigrateDestinationFieldCollection::getKeySchema()
    );

    // We use the same CSV as from the candidate profile migration.
    $this->source = new MigrateSourceCSV(drupal_get_path('module', 'drop_jobs_demo') . '/import/candidate_personal.csv', $this->csvcolumns(), array('header_rows' => 1));

    $this->destination = new MigrateDestinationFieldCollection('field_candidate_personal_info', array(
      'host_entity_type' => 'profile2'
    ));

    $this->addFieldMapping('host_entity_id', 'id')
      ->sourceMigration('DropJobsCandidates');

    $arguments = array(
      'administrative_area' => array('source_field' => 'province'),
      'locality' => array('source_field' => 'city'),
      'postal_code' => array('source_field' => 'postal_code'),
      'thoroughfare' => array('source_field' => 'street'),
      'premise' => array('source_field' => 'premise'),
    );
    $this->addFieldMapping('field_address', 'country')->arguments($arguments);

    $this->addFieldMapping('field_gender', 'gender');
    $this->addFieldMapping('field_marital_status', 'marital');
    $this->addFieldMapping('field_birthday', 'birthday');
    $this->addFieldMapping('field_candidate_notes', 'about');

    $this->addFieldMapping('field_photo', 'photo');
    $this->addFieldMapping('field_photo:file_replace')
      ->defaultValue(FILE_EXISTS_REPLACE);
    $this->addFieldMapping('field_photo:source_dir')
      ->defaultValue(drupal_get_path('module', 'drop_jobs_demo') . '/import/images');

    $this->addFieldMapping('field_first_name', 'first_name');
    $this->addFieldMapping('field_last_name', 'last_name');
    $this->addFieldMapping('field_salutation', 'salutation');

    $this->addUnmigratedDestinations(array(
      'field_candidate_notes:language',
      'field_first_name:language',
      'field_last_name:language',
      'field_photo:file_class',
      'field_photo:language',
      'field_photo:destination_dir',
      'field_photo:destination_file',
      'field_photo:preserve_files',
      'field_photo:alt',
      'field_photo:title',
      // This is computed automatically.
      'field_geofield',
      // This is ignored for now because we must first migrate this profile
      // before migrating this field which is a field collection item.
      'field_phone',
    ));

    $this->addUnmigratedSources(array(
      'dummy_id',
      'user',
      'province',
      'city',
      'postal_code',
      'street',
      'premise',
    ));
  }

  public function csvcolumns() {
    return array(
      array('dummy_id', 'Dummy id'),
      array('id', 'User id'),
      array('user', 'User name'),
      array('gender', 'Candidate gender'),
      array('birthday', 'Candidate birthday'),
      array('marital', 'Candidate marital status'),
      array('country', 'Organization address country'),
      array('province', 'Organization address province'),
      array('city', 'Organization address city'),
      array('postal_code', 'Organization address postal code'),
      array('street', 'Organization address street'),
      array('premise', 'Organization address premise'),
      array('about', 'Candidate about'),
      array('first_name', 'User first name'),
      array('last_name', 'User last name'),
      array('photo', 'User photo'),
      array('salutation', 'User salutation'),
    );
  }

}