<?php
/**
 * @file
 * Employers migration class for Drop Jobs Demo.
 */

/**
 * Class for importing employer profiles.
 */
class DropJobsEmployers extends DropJobsMigration {

  public function __construct() {
    parent::__construct();
    $this->description = t('Import Employer profiles.');
    $this->dependencies = array('DropJobsUsers', 'DropJobsOrganizations');

    $this->map = new MigrateSQLMap($this->machineName,
      array(
        'id' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => TRUE,
        )
      ),
      MigrateDestinationProfile2::getKeySchema()
    );

    $this->source = new MigrateSourceCSV(drupal_get_path('module', 'drop_jobs_demo') . '/import/employer.csv', $this->csvcolumns(), array('header_rows' => 1));

    $this->destination = new MigrateDestinationProfile2('employer');

    $this->addFieldMapping('uid', 'user')->defaultValue(1)->sourceMigration('DropJobsUsers');

    $this->addFieldMapping('field_organization', 'organization')
      ->sourceMigration('DropJobsOrganizations');

    $this->addFieldMapping('field_first_name', 'first_name');
    $this->addFieldMapping('field_last_name', 'last_name');

    $this->addFieldMapping('field_photo', 'photo');
    $this->addFieldMapping('field_photo:file_replace')
      ->defaultValue(FILE_EXISTS_REPLACE);
    $this->addFieldMapping('field_photo:source_dir')
      ->defaultValue(drupal_get_path('module', 'drop_jobs_demo') . '/import/images');

    $this->addUnmigratedDestinations(array(
      'revision_uid',
      'language',
      'field_first_name:language',
      'field_last_name:language',
      'field_photo:file_class',
      'field_photo:language',
      'field_photo:destination_dir',
      'field_photo:destination_file',
      'field_photo:preserve_files',
      'field_photo:alt',
      'field_photo:title',
      'field_phone',
    ));

    $this->addUnmigratedSources(array(
      'dummy_id',
      'id',
    ));
  }

  public function csvcolumns() {
    return array(
      array('dummy_id', 'Dummy id'),
      array('id', 'User id'),
      array('user', 'User name'),
      array('first_name', 'User first name'),
      array('last_name', 'User last name'),
      array('photo', 'User photo'),
      array('organization', 'User organization'),
    );
  }

}